@@ -210,6 +210,10 @@ class PrivatePath(Router):
     @route("GET /organizations/{org_id}/instances/{instance_id}/activitylog{ctype}")
     def get_instance_activitylog(self, org_id, instance_id, auth, cookies, params=None, ctype=".json"): pass
 
+    @play_auth
+    @route("GET /organizations/{org_id}/instances/{instance_id}/workflowHistory{ctype}")
+    def get_instance_workflowhistory(self, org_id, instance_id, auth, cookies, ctype=".json"): pass
+
     @play_auth
     @route("POST /organizations/{org_id}/instances/{instance_id}/{action}{ctype}")
     def post_instance_action(self, org_id, instance_id, action, auth, cookies, data="{}", ctype=".json"): pass
@@ -462,6 +466,10 @@ class PublicPath(PrivatePath):
     @route("GET /api/1/instances/{instance_id}")
     def api1_instance_details(self, instance_id, auth): pass
 
+    @basic_auth
+    @route("GET /api/1/instances/{instance_id}/schedules")
+    def api1_instance_scheduled_workflows(self, instance_id, auth): pass
+
     @basic_auth
     @route("DELETE /api/1/instances/{instance_id}")
     def api1_instance_delete(self, instance_id, auth, params): pass
@@ -474,6 +482,18 @@ class PublicPath(PrivatePath):
     @route("POST /api/1/instances/{instance_id}/{workflow}")
     def api1_instance_run_workflow(self, instance_id, workflow, auth, json): pass
 
+    @basic_auth
+    @route("POST /api/1/instances/{instance_id}/{workflow}/schedule")
+    def api1_instance_schedule_workflow(self, instance_id, workflow, auth, json): pass
+
+    @basic_auth
+    @route("POST /api/1/instances/{instance_id}/{workflow}/reschedule")
+    def api1_instance_reschedule_workflow(self, instance_id, workflow, auth, json): pass
+
+    @basic_auth
+    @route("PUT /api/1/instances/{instance_id}/configuration")
+    def api1_instance_reconfigure(self, instance_id, auth, json): pass
+
     @basic_auth
     @route("PUT /api/1/instances/{instance_id}/userData")
     def api1_instance_set_user_data(self, instance_id, json, auth): pass
